@@ -1,5 +1,6 @@
-SERVER_URL = 'http://localhost:5000'
-WEB_URL = 'http://localhost:5000'
+PORT = '5005'
+SERVER_URL = f'http://localhost:{PORT}'
+WEB_URL = f'http://localhost:{PORT}'
 SLACK_BOT_TOKEN = 'XXX'
 SLACK_CHANNEL = 'XXX'
 AUTH0_DOMAIN = 'XXX'
